@@ -22,19 +22,14 @@ class SavedFiltersAPI(BaseAPI):
         return saved_filters_payload.GetResponse.from_json(response.text).to_saved_filter()
 
     def create(self, saved_filter: SavedFilter) -> SavedFilter:
-        SavedFiltersAPI.check_fields(saved_filter)
-
         api_call = saved_filters.create_saved_filter()
-        payload = saved_filters_payload.CreateRequest(saved_filter)
+        payload = saved_filters_payload.CreateRequest.from_custom_application(saved_filter)
         response = self.send(api_call, payload)
         return saved_filters_payload.CreateResponse.from_json(response.text).to_saved_filter()
 
     def update(self, saved_filter: SavedFilter) -> SavedFilter:
-        assert saved_filter.id is not None, "SavedFilter ID has to be provided"
-        SavedFiltersAPI.check_fields(saved_filter)
-
         api_call = saved_filters.update_saved_filter(saved_filter.id)
-        payload = saved_filters_payload.UpdateRequest(saved_filter)
+        payload = saved_filters_payload.UpdateRequest.from_custom_application(saved_filter)
         response = self.send(api_call, payload)
         return saved_filters_payload.UpdateResponse.from_json(response.text).to_saved_filter()
 
@@ -42,11 +37,3 @@ class SavedFiltersAPI(BaseAPI):
         api_call = saved_filters.delete_saved_filter(saved_filter_id)
         response = self.send(api_call)
         return response.http_status_code == HTTPStatus.NO_CONTENT
-
-    @staticmethod
-    def check_fields(saved_filter: SavedFilter):
-        assert saved_filter.filter_name is not None, "Filter must have name"
-        if saved_filter.filters is not None:
-            assert saved_filter.filters.connector is not None
-            assert all(i.connector is not None for i in saved_filter.filters.filterGroups)
-            assert all(i.not_ is not None for i in saved_filter.filters.filterGroups)
