@@ -1,10 +1,10 @@
-from dataclasses import dataclass
 from copy import deepcopy
-from typing import Dict, List, Any
+from dataclasses import dataclass
+from typing import Any, Dict, List
 
-from kentik_api.requests_payload.conversions import convert, convert_or_none, from_dict, dict_from_json
+from kentik_api.public.plan import Plan, PlanDevice, PlanDeviceType
 from kentik_api.public.types import ID
-from kentik_api.public.plan import Plan, PlanDeviceType, PlanDevice
+from kentik_api.requests_payload.conversions import convert, convert_or_none, dict_from_json, from_dict
 
 
 @dataclass()
